@@ -6,13 +6,13 @@ import argparse
 import datetime
 import errno
 import pkg_resources
-from ansible_deployer.modules.globalvars import SUBCOMMANDS
 from ansible_deployer.modules.configs.config import Config
 from ansible_deployer.modules.locking.locking import Locking
 from ansible_deployer.modules.outputs.logging import Loggers
 from ansible_deployer.modules.validators.validate import Validators
 from ansible_deployer.modules.runners.run import Runners
 from ansible_deployer.modules import misc
+from ansible_deployer.modules import globalvars
 
 def parse_options(argv):
     """Generic function to parse options for all commands, we validate if the option was allowed for
@@ -20,7 +20,8 @@ def parse_options(argv):
     parser = argparse.ArgumentParser(add_help=True)
 
     parser.add_argument("subcommand", nargs='*', default=None, metavar="SUBCOMMAND",
-                        help='Specify subcommand to execute. Available commands: '+str(SUBCOMMANDS))
+                        help='Specify subcommand to execute. Available commands: '+ \
+                        str(globalvars.SUBCOMMANDS))
     parser.add_argument("--infrastructure", "-i", nargs=1, default=[None], metavar="INFRASTRUCTURE",
                         help='Specify infrastructure for deploy.')
     parser.add_argument("--stage", "-s", nargs=1, default=[None], metavar="STAGE",
@@ -49,6 +50,8 @@ def parse_options(argv):
                         help='Setup repo outside of workdir in requested path. This option applies'
                         ' only to infrastructures with allow_user_checkout enabled in infra'
                         ' config!')
+    parser.add_argument("--no-color", default=False, action="store_true", help='Disable coloring'
+                        'of console messages.')
 
     arguments = parser.parse_args(argv)
 
@@ -57,16 +60,22 @@ def parse_options(argv):
         print(f"ansible-deployer version: {version}")
         sys.exit(0)
 
+    if arguments.no_color:
+        PRINT_FAIL = PRINT_END = ""
+    else:
+        PRINT_FAIL = globalvars.PRINT_FAIL
+        PRINT_END = globalvars.PRINT_END
+
     if not arguments.subcommand:
-        sub_string = ", ".join(SUBCOMMANDS).strip(", ")
-        print(f"[CRITICAL]: First positional argument (subcommand) is required! Available commands"
-              f" are: {sub_string}.")
+        sub_string = ", ".join(globalvars.SUBCOMMANDS).strip(", ")
+        print(f"{PRINT_FAIL}[CRITICAL]: First positional argument (subcommand) is required!"
+              f" Available commands are: {sub_string}.{PRINT_END}")
         sys.exit(57)
 
     options = {}
     options["subcommand"] = arguments.subcommand[0].lower()
-    Validators.verify_subcommand(options["subcommand"])
-    Validators.verify_switches(arguments.subcommand)
+    Validators.verify_subcommand(options["subcommand"], arguments.no_color)
+    Validators.verify_switches(arguments.subcommand, arguments.no_color)
 
     options["switches"] = arguments.subcommand[1:]
     options["infra"] = arguments.infrastructure[0]
@@ -79,14 +88,10 @@ def parse_options(argv):
     options["syslog"] = arguments.syslog
     options["limit"] = arguments.limit[0]
     options["raw_output"] = arguments.raw_runner_output
-    if arguments.self_setup[0]:
-        options["self_setup"] = os.path.abspath(arguments.self_setup[0])
-    else:
-        options["self_setup"] = None
-    if arguments.conf_dir[0]:
-        options["conf_dir"] = os.path.abspath(arguments.conf_dir[0])
-    else:
-        options["conf_dir"] = None
+    options["self_setup"] = os.path.abspath(arguments.self_setup[0]) if arguments.self_setup[0] \
+                            else None
+    options["conf_dir"] = os.path.abspath(arguments.conf_dir[0]) if arguments.conf_dir[0] else None
+    options["no_color"] = arguments.no_color
 
     return options
 
@@ -95,7 +100,8 @@ def main():
     start_ts = datetime.datetime.now().strftime("%Y%m%d_%H%M%S")
 
     if len(sys.argv) < 2:
-        print("[CRITICAL]: Too few arguments", file=sys.stderr)
+        print(f"{globalvars.PRINT_FAIL}[CRITICAL]: Too few arguments{globalvars.PRINT_END}",
+              file=sys.stderr)
         sys.exit(2)
     options = parse_options(sys.argv[1:])
 
