@@ -3,3 +3,5 @@
 APP_CONF = "/etc/ansible-deployer"
 CFG_PERMISSIONS = "0o644"
 SUBCOMMANDS = ("run", "lock", "unlock", "verify", "show")
+PRINT_FAIL = '\033[91m'
+PRINT_END = '\033[0m'
